<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="163"/>
        <source>Administrator Access Required</source>
        <translation>Rootrechte erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="164"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Dieser Vorgang erfordert Rootrechte. Bitte starten Sie das Programm erneut und geben auf Anforderung Ihr Paßwort ein.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="57"/>
        <location filename="../src/mainwindow.ui" line="198"/>
        <source>Please select the location of your installation:</source>
        <translation>Bitte wählen Sie den Ort Ihrer Installation:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <location filename="../src/mainwindow.ui" line="211"/>
        <source>Select drive:</source>
        <translation>Laufwerk auswählen:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <location filename="../src/mainwindow.ui" line="228"/>
        <source>Select partition:</source>
        <translation>Partition auswählen:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="249"/>
        <source>Frugal mode:</source>
        <translation>Genügsamer Modus:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Boot options:</source>
        <translation>Boot-Optionen:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="129"/>
        <location filename="../src/mainwindow.ui" line="313"/>
        <source>UEFI entry name:</source>
        <translation>UEFI Eintrag:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <source>UEFI manager</source>
        <translation>UEFI-Verwaltung</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="41"/>
        <source>EFI stub installer</source>
        <translation>EFI Rumpfinstallation</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="47"/>
        <source>This options copies the kernel and initrd files to ESP (EFI System Partition) and creates an UEFI entry that allows to boot the installation directly, bypassing GRUB and other bootloaders. To boot using the created UEFI entry, access the UEFI boot selection menu at startup by pressing the appropriate key for your device (e.g., F12, F9, or Esc, depending on the manufacturer).</source>
        <translation>Diese Option kopiert den Systemkern und die Initrd-Dateien in die EFI Systempartition (ESP) und erzeugt einen UEFI Eintrag in Ihrer UEFI-fähigen Hardware, der es gestattet, direkt in die antiX- oder MX-Installation zu booten, unter Umgehung von Bootloadern wie z.B. Grub. Um den Eintrag zu verwenden, gehen Sie beim Systemstart ins UEFI Boot-Auswahlmenü, das Ihre Hardware bereitstellt, indem sie zur richtigen Zeit die entsprechende Taste (z.B. F12, F9 oder ESC, je nach Hersteller) drücken, und wählen dort den hier erzeugten Eintrag.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="115"/>
        <source>Kernel to boot:</source>
        <translation>Systemkern (»kernel«), in den gebootet werden soll:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="122"/>
        <source>Kernel options:</source>
        <translation>Kerneloptionen:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="393"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="396"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="402"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="418"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="427"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="443"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="36"/>
        <source>Manage UEFI entries</source>
        <translation>UEFI Einträge verwalten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="166"/>
        <source>Frugal EFI stub installer</source>
        <translation>Genügsame EFI Rumpfinstallation</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <source>This option is meant to create a bootable entry for MX and antiX frugal installation, it creates an EFI boot entry for launching the installation directly, bypassing GRUB and other bootloaders. To boot using the created UEFI entry, access the UEFI boot selection menu at startup by pressing the appropriate key for your device (e.g., F12, F9, or Esc, depending on the manufacturer).</source>
        <translation>Diese Option dient dazu, einen Booteintrag für genügsame MX und antiX Installationen („frugal”) zu erzeugen. Sie erstellt einen EFI-Booteintrag, der die hinterlegte Installation direkt läd, unter Umgehung von Bootloadern wie z.B. Grub. Um den Eintrag zu verwenden, gehen Sie beim Systemstart ins UEFI Boot-Auswahlmenü, das Ihre Hardware bereitstellt, indem sie zur richtigen Zeit die entsprechende Taste (z.B. F12 oder ESC, je nach Hersteller) drücken, und wählen dort den hier erzeugten Eintrag.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="446"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="452"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="465"/>
        <location filename="../src/mainwindow.cpp" line="885"/>
        <location filename="../src/mainwindow.cpp" line="1677"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="503"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="718"/>
        <location filename="../src/mainwindow.cpp" line="908"/>
        <location filename="../src/mainwindow.cpp" line="1487"/>
        <location filename="../src/mainwindow.cpp" line="1497"/>
        <source>UEFI Installer</source>
        <translation>UEFI-Installationsprogramm</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="719"/>
        <source>A recent frugal install has been detected. Do you wish to add a UEFI entry direct to your UEFI system menu?</source>
        <translation>Eine aktuelle genügsame Installation wurde erkannt. Möchten Sie einen UEFI Eintrag dafür zu Ihrem UEFI Systemmenü hinzufügen?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="956"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Die UUID für %1 konnte nicht abgerufen werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="963"/>
        <source>Enter passphrase to unlock %1 encrypted partition:</source>
        <translation>Bitte geben Sie die Paßphrase zum aufsperren der verschlüsselten Partition %1 ein:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <source>Passphrase entry cancelled or empty for %1</source>
        <translation>Die Paßphrase für %1 wurde nicht angegeben oder Abbruch durch den Benutzer.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="974"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Der LUKS-Container %1 konnte nicht geöffnet werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1488"/>
        <source>Are you sure this is the MX or antiX Frugal installation location?
Missing mandatory files in directory: </source>
        <translation>Sind Sie sicher, daß dies der korrekte Pfad zu Ihrer genügsamen MX- oder antiX-Installation ist?
Es fehlen obligatorische Dateien im Verzeichnis: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1561"/>
        <source>Not enough space on the EFI System Partition to copy the kernel and initrd files.</source>
        <translation>Nicht ausreichend Speicherplatz auf der EFI Systempartition um den Systemkern und die initrd-Dateien dorthin zu kopieren.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1614"/>
        <source>All fields are required</source>
        <translation>Alle Felder erforderlich</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1637"/>
        <source>Could not select ESP</source>
        <translation>ESP nicht wählbar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1655"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>Select EFI file</source>
        <translation>EFI-Datei auswählen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>EFI-Dateien (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <location filename="../src/mainwindow.cpp" line="956"/>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <location filename="../src/mainwindow.cpp" line="974"/>
        <location filename="../src/mainwindow.cpp" line="1697"/>
        <location filename="../src/mainwindow.cpp" line="1821"/>
        <location filename="../src/mainwindow.cpp" line="1873"/>
        <location filename="../src/mainwindow.cpp" line="1884"/>
        <location filename="../src/mainwindow.cpp" line="1891"/>
        <location filename="../src/mainwindow.cpp" line="1902"/>
        <location filename="../src/mainwindow.cpp" line="1912"/>
        <location filename="../src/mainwindow.cpp" line="1927"/>
        <location filename="../src/mainwindow.cpp" line="1932"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Konnte den Quell-Einhängepunkt für %1 nicht finden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>Set name</source>
        <translation>Name festlegen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Name des UEFI-Menüpunkts eingeben</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Etwas lief schief, Eintrag konnte nicht erstellt werden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="745"/>
        <location filename="../src/mainwindow.cpp" line="787"/>
        <location filename="../src/mainwindow.cpp" line="1709"/>
        <source>Timeout: %1 seconds</source>
        <translation>Timeout: %1 Sekunden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="747"/>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <location filename="../src/mainwindow.cpp" line="1726"/>
        <source>Boot Next: %1</source>
        <translation>Boote nächstes: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="749"/>
        <source>Boot Current: %1</source>
        <translation>Boote aktuelles: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="762"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Mit den Schaltflächen Auf/Ab oder durch Ziehen und Ablegen von Elementen können Sie die Boot-Reihenfolge ändern.
- Die Elemente werden in der Startreihenfolge aufgelistet.
- Ausgegraute Zeilen sind inaktiv.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="773"/>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Set ac&amp;tive</source>
        <translation>Auf ak&amp;tiv setzen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="774"/>
        <source>&amp;Add entry</source>
        <translation>&amp;Eintrag hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="775"/>
        <source>Boot &amp;next</source>
        <translation>Boote &amp;nächstes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="776"/>
        <source>Move &amp;down</source>
        <translation>&amp;Verschieben abwärts</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="777"/>
        <source>&amp;Remove entry</source>
        <translation>&amp;Eintrag entfernen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="779"/>
        <source>Re&amp;set next</source>
        <translation>Näch&amp;stes zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="780"/>
        <source>Change &amp;timeout</source>
        <translation>Ändern &amp;Timeout</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="781"/>
        <source>Move &amp;up</source>
        <translation>&amp;Verschieben aufwärts</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <source>not set, will boot using list order</source>
        <translation>nicht gesetzt, boote mit Reihenfolge in Liste</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>Set &amp;inactive</source>
        <translation>Auf &amp;inaktiv setzen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="908"/>
        <source>Failed to open grub.entry file.</source>
        <translation>Die Datei grub.entry konnte nicht geöffnet werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1658"/>
        <source>Tool for managing UEFI boot entries</source>
        <translation>Verwaltungswerkzeug für UEFI Booteinträge</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1821"/>
        <source>Both old and new EFI labels must be specified</source>
        <translation>Sowohl alte als auch neue EFI Bezeichner müssen angegeben werden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1874"/>
        <source>Multiple boot entries found for label &apos;%1&apos;: %2 and %3;</source>
        <translation>Mehrfache Booteinträge für die Bezeichner &apos;%1&apos;: %2 und %3 vorhanden;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1884"/>
        <source>No EFI data found for label &apos;%1&apos;.</source>
        <translation>Keine EFI Daten für Bezeichner &apos;%1&apos; vorhanden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1892"/>
        <source>EFI label &apos;%1&apos; is linked to an unknown partition &apos;%2&apos;.</source>
        <translation>EFI Bezeichner &apos;%1&apos; ist mit einer unbekannten Partition &apos;%2&apos; verknüpft.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1903"/>
        <source>Unexpected device name format &apos;%1&apos; for partition related to the label.</source>
        <translation>Unerwartetes Gerätenamensformat &apos;%1&apos; der Partition, auf die sich der Bezeichner bezieht.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1913"/>
        <source>Device partition number [%1] differs from EFI entry partition number [%2].</source>
        <translation>Partitionsnummer [%1] des Gerätes weicht von der im EFI-Eintrag hinterlegten Partitionsnummer [%2] ab.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1927"/>
        <source>Failed to delete old boot entry</source>
        <translation>Der alte Booteintrag konnte nicht entfernt werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1932"/>
        <source>Failed to create new boot entry</source>
        <translation>Der neue Booteintrag konnte nicht erzeugt werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1497"/>
        <source>Failed to read grub.entry file.</source>
        <translation>Die Datei grub.entry konnte nicht gelesen werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="893"/>
        <location filename="../src/mainwindow.cpp" line="1510"/>
        <source>Install</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1516"/>
        <source>Select Frugal Directory</source>
        <translation>Wählen Sie das Verzeichnis der genügsamen Installation aus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1523"/>
        <source>No EFI System Partitions found.</source>
        <translation>Es konnte keine EFI Partition gefunden werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1529"/>
        <source>Select EFI System Partition</source>
        <translation>Wählen Sie die EFI Systempartition</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1530"/>
        <source>EFI System Partitions:</source>
        <translation>EFI Systempartitionen:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1543"/>
        <source>No EFI System Partition selected</source>
        <translation>Es wurde keine EFI Systempartition ausgewählt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1550"/>
        <source>Could not mount selected EFI System Partition</source>
        <translation>Die gewählte EFI Systempartition konnte nicht eingehängt werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1577"/>
        <location filename="../src/mainwindow.cpp" line="1621"/>
        <source>Could not mount partition. Please make sure you selected the correct partition.</source>
        <translation>Die Partition konnte nicht eingehängt werden. Bitte prüfen Sie, ob Sie die korrekte Partition ausgewählt haben.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1586"/>
        <source>No directory selected</source>
        <translation>Es wurde kein Verzeichnis ausgewählt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1606"/>
        <location filename="../src/mainwindow.cpp" line="1643"/>
        <source>EFI stub installed successfully.</source>
        <translation>Der EFI-Rumpf wurde erfolgreich installiert.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1608"/>
        <location filename="../src/mainwindow.cpp" line="1645"/>
        <source>Failed to install EFI stub.</source>
        <translation>Die Installation des EFI-Rumpfes ist fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1656"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1660"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1661"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1669"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1697"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Etwas lief schief, Boot-Reihenfolge konnte nicht gespeichert werden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1705"/>
        <source>Set timeout</source>
        <translation>Timeout einstellen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1705"/>
        <source>Timeout in seconds:</source>
        <translation>Timeout in Sekunden:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1744"/>
        <source>Removal confirmation</source>
        <translation>Entfernen bestätigen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1745"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Sind Sie sicher, dass Sie diesen Booteintrag löschen wollen??
%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="99"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="100"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="101"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="125"/>
        <source>Error: Changelog file is missing.</source>
        <translation>Fehler: Änderungsprotokolldatei fehlt.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="127"/>
        <source>Error: Required utility &apos;zless&apos; is missing.</source>
        <translation>Fehler: Das erforderliche Hilfsprogramm ‘zless’ ist nicht installiert.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="134"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>uefi-manager is a tool for managing UEFI boot entries</source>
        <translation>Die UEFI Verwaltung ist ein Werkzeug zum Bearbeiten von UEFI Booteinträgen in Ihrer UEFI-fähigen Hardware.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="88"/>
        <source>Perform EFI Stub installation for frugal installation.</source>
        <translation>Den UEFI-Rumpf für eine genügsame Installation installieren.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="66"/>
        <location filename="../src/main.cpp" line="95"/>
        <source>UEFI Manager</source>
        <translation>UEFI Verwaltung</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="89"/>
        <source>Run in test mode (bypass UEFI detection for GUI testing).</source>
        <translation>Ausführung im Testmodus (Zum Test der GUI die UEFI-Erkennung übergehen)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>This system doesn&apos;t seem to support UEFI, or was not booted in UEFI mode. Exiting.</source>
        <translation>Dieses System scheint nicht über UEFI zu verfügen, oder es wurde nicht im UEFI-Modus gebootet. Ausführung abgebrochen.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="107"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="108"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sie sind als Root („Administrator”) am System angemeldet. Bitte melden Sie sich ab und als normaler Benutzer wieder an, um dieses Programm zu verwenden.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>version:</source>
        <translation>Version:</translation>
    </message>
</context>
</TS>